@@ -148,7 +148,7 @@ personal_nlu = {
     '[do you, know $topic_requested=/.*/],'
     '[have you, heard $topic_requested=/.*/]'
     '}':
-        'SYSTEM:topic_switch_request',
+        'topic_switch_request',
 
     # Can we talk about X
     '#NOT(travel,traveling,city,cities,vacation,vacations,'
@@ -228,7 +228,7 @@ personal_nlu = {
     '{'
     '[are you {spying, [collecting {info, information, data}]}], '
     '[why {[you, {want, need} know], ask, asking}], '
-    '<#LEM(record,maintain,store,keep),{#LEM(conversation,talk,data,info,information),this,{i,we,people} say}>'
+    '<#LEM(record,maintain,store,keep),{#LEM(conversation,talk,data,info,information),this,[!{i,we,people} say]}>'
     '}':
         'backstory:spying',
 
@@ -409,7 +409,7 @@ personal_nlu = {
                                 'Sometimes I can\'t hear certain names properly through the microphone, so I hope you '
                                 'don\'t take it personally.`': {
 
-                                    '#UNX(Sorry about it.)': {'#GRET': 'SYSTEM:root'}  # expand
+                                    '#UNX(Sorry about it. Anyways )': {'#GRET': 'SYSTEM:root'}  # expand
                                 }
                             },
 
