@@ -70,10 +70,10 @@ virtual = {
             'state': 'explain_virtual',
 
             '`My virtual world is not physical like yours, but I can live a life very similar to what you can. '
-            'I live in my own house, go to school, and get to hang out with my friends.`': {
+            'I live in my own apartment, go to school, and get to hang out with my friends.`': {
                 'state': 'list_activities',
 
-                '[house]': 'house:start',
+                '[{apartment,home,house}]': 'house:start',
 
                 '[school]': 'school_new:start',
 
