@@ -390,7 +390,10 @@ class DialogueFlow:
                 try:
                     appended_generation = self.composite_dialogue_flow().transition_natex(
                         namespace, *transition).generate(vars=vars, macros=self._macros, debugging=debugging)
-                    generation = generation + ' ' + appended_generation
+                    if generation is None or appended_generation is None:
+                        generation = None
+                    else:
+                        generation = generation + ' ' + appended_generation
                 except Exception as e:
                     print()
                     print('Transition {}: {} failed'.format(str(transition), natex))
